==> org.knime.base.source_2.5.2.0032292.jar: org/knime/base/node/mine/bfn/BasisFunctionPredictorRowIterator.java <==
/*
 * ------------------------------------------------------------------------
 *
 *  Copyright (C) 2003 - 2011
 *  University of Konstanz, Germany and
 *  KNIME GmbH, Konstanz, Germany
 *  Website: http://www.knime.org; Email: contact@knime.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME GMBH herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * --------------------------------------------------------------------- *
 */
package org.knime.base.node.mine.bfn;

import java.util.Map;

import org.knime.base.data.append.column.AppendedColumnRow;
import org.knime.core.data.DataCell;
import org.knime.core.data.DataRow;
import org.knime.core.data.RowIterator;
import org.knime.core.data.RowKey;

/**
 * Class wraps a row iterator in order to exents the given
 * {@link org.knime.core.data.DataRow} elements by on cell (resp. column
 * for the {@link org.knime.core.data.DataTable}).
 * 
 * @author Thomas Gabriel, University of Konstanz
 */
final class BasisFunctionPredictorRowIterator extends RowIterator {
    /*
     * The row iterator of the input data.
     */
    private final RowIterator m_rowIt;

    /*
     * Keeps the row key to class label.
     */
    private final Map<RowKey, DataCell> m_map;

    /**
     * Creates a new row iterator used for the basisfunction predictor node
     * which extends the input rows by a new, additional class label column.
     * 
     * @param rowIt the row iterator of the input data
     * @param map maps the row keys to class labels
     */
    BasisFunctionPredictorRowIterator(final RowIterator rowIt,
            final Map<RowKey, DataCell> map) {
        assert (rowIt != null);
        m_rowIt = rowIt;
        assert (map != null);
        m_map = map;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean hasNext() {
        return m_rowIt.hasNext();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public DataRow next() {
        DataRow row = m_rowIt.next();
        DataCell classInfo = m_map.get(row.getKey().getString());
        return new AppendedColumnRow(row, classInfo);
    }
}

==> org.knime.base.source_2.7.2.0036614.jar: org/knime/base/node/mine/bfn/BasisFunctionPredictorRowIterator.java <==
/*
 * ------------------------------------------------------------------------
 *
 *  Copyright (C) 2003 - 2011
 *  University of Konstanz, Germany and
 *  KNIME GmbH, Konstanz, Germany
 *  Website: http://www.knime.org; Email: contact@knime.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME GMBH herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * --------------------------------------------------------------------- *
 */
package org.knime.base.node.mine.bfn;

import java.util.Map;

import org.knime.base.data.append.column.AppendedColumnRow;
import org.knime.core.data.DataCell;
import org.knime.core.data.DataRow;
import org.knime.core.data.RowIterator;
import org.knime.core.data.RowKey;

/**
 * Class wraps a row iterator in order to exents the given
 * {@link org.knime.core.data.DataRow} elements by on cell (resp. column
 * for the {@link org.knime.core.data.DataTable}).
 *
 * @author Thomas Gabriel, University of Konstanz
 */
final class BasisFunctionPredictorRowIterator extends RowIterator {
    /*
     * The row iterator of the input data.
     */
    private final RowIterator m_rowIt;

    /*
     * Keeps the row key to class label.
     */
    private final Map<RowKey, DataCell> m_map;

    /**
     * Creates a new row iterator used for the basisfunction predictor node
     * which extends the input rows by a new, additional class label column.
     *
     * @param rowIt the row iterator of the input data
     * @param map maps the row keys to class labels
     */
    BasisFunctionPredictorRowIterator(final RowIterator rowIt,
            final Map<RowKey, DataCell> map) {
        assert (rowIt != null);
        m_rowIt = rowIt;
        assert (map != null);
        m_map = map;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean hasNext() {
        return m_rowIt.hasNext();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public DataRow next() {
        DataRow row = m_rowIt.next();
        DataCell classInfo = m_map.get(row.getKey());
        return new AppendedColumnRow(row, classInfo);
    }
}
